ERMLPEInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ERMLPEInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ERMLPEInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
